@@ -140,12 +140,7 @@ void Project::addFile(QTreeView* treeView, QSortFilterProxyModel* sort, const QS
             delete cp;
             goto coursera_done;
         }
-        cp->course = in.readLine();
-        if (in.status() != QTextStream::Ok) {
-            delete cp;
-            goto coursera_done;
-        }
-        cp->checkpwdSid= in.readLine();
+        cp->assignmentKey = in.readLine();
         if (in.status() != QTextStream::Ok) {
             delete cp;
             goto coursera_done;
@@ -253,20 +248,16 @@ QString Project::fileAtIndex(const QModelIndex &index)
 
 Qt::ItemFlags Project::flags(const QModelIndex& index) const
 {
-    if (index==editable) {
-        return Qt::ItemIsSelectable | Qt::ItemIsEnabled | Qt::ItemIsEditable;
-    } else {
-        QStandardItem* item = itemFromIndex(index);
-        if (!item->hasChildren() && (item==mzn || item==dzn || item==other) )
-            return Qt::ItemIsSelectable;
-        return Qt::ItemIsSelectable | Qt::ItemIsEnabled;
-    }
+    QStandardItem* item = itemFromIndex(index);
+    if (!item->hasChildren() && (item==mzn || item==dzn || item==other) )
+        return Qt::ItemIsSelectable;
+    return Qt::ItemIsSelectable | Qt::ItemIsEnabled | Qt::ItemIsEditable;
 }
 
 QStringList Project::dataFiles(void) const
 {
     QStringList ret;
-    for (QMap<QString,QModelIndex>::const_iterator it = _files.begin(); it != _files.end(); ++it) {
+    for (QMap<QString,QPersistentModelIndex>::const_iterator it = _files.begin(); it != _files.end(); ++it) {
         if (it.key().endsWith(".dzn"))
             ret << it.key();
     }
@@ -298,11 +289,6 @@ void Project::removeFile(const QString &fileName)
     }
 }
 
-void Project::setEditable(const QModelIndex &index)
-{
-    editable = index;
-}
-
 void Project::setModified(bool flag, bool files)
 {
     if (!projectRoot.isEmpty()) {
@@ -337,7 +323,6 @@ void Project::setModified(bool flag, bool files)
 
 bool Project::setData(const QModelIndex& index, const QVariant& value, int role)
 {
-    editable = QModelIndex();
     QString oldName = itemFromIndex(index)->text();
     if (oldName==value.toString())
         return false;
@@ -442,7 +427,8 @@ void Project::currentDataFileIndex(int i, bool init)
         _currentDatafileIndex = i;
         ui->conf_data_file->setCurrentIndex(i);
     } else {
-        checkModified();
+        if (i < ui->conf_data_file->count()-1)
+            checkModified();
     }
 }
 
